SUBROUTINE cos_receive_fld 

!!---------------------------------------------------------------------
!!              ***  ROUTINE receive_fld  ***
!!
!! ** Purpose : - Prepare and receive coupling fields to OASIS
!!    
!!----------------------------------------------------------------------

USE oas_cos_vardef

USE data_modelconfig, ONLY : &
  ke, ke1,         &
  dt,              &
  ie, je,          & 
  istartpar,       &
  iendpar,         &
  jstartpar,       &
  jendpar,         &
  ie_tot,          &
  je_tot

USE data_parameters,  ONLY : &
  ireals,          &
  iintegers

USE data_parallel,    ONLY : &
  isubpos,         & ! positions of the subdomains in the total domain
  nboundlines,     &     
  my_cart_id,      &
  num_compute,     &
  sendbuf,         &
  isendbuflen,     &
  imp_reals,       &
  icomm_cart,      &
  my_cart_neigh,   &
  ncomm_type,      &
  ldatatypes

USE environment,      ONLY : &
  exchg_boundaries

USE data_runcontrol , ONLY : &
  nnow  ,         & ! corresponds to ntstep
  nnew  ,         & ! corresponds to ntstep + 1
  ntstep,         & !
  nstart,         & ! first time step of the forecast
  ltime,          &
  nstop          

    
  ! 1. constant fields for the reference atmosphere                     (unit)
  ! -----------------------------------------------
    
USE data_fields,      ONLY : &
  t_s       ,     & ! temperature of the ground surface             (  k  )
  qv_s      ,     & ! specific water vapor content on the surface   (kg/kg)

  qvsflx     ,    & ! surface flux of water vapour                  (1/m2s)
  umfl_s    ,     & ! u-momentum flux (surface)                     ( N/m2)
  vmfl_s    ,     & ! v-momentum flux (surface)                     ( N/m2)
  shfl_s    ,     & ! sensible heat flux (surface)                  ( W/m2)
  lhfl_s            ! latent heat flux (surface)                    ( W/m2)
 


USE parallel_utilities,  ONLY:  &
  gather_field,     &
  distribute_field

USE netcdf


IMPLICIT NONE

!
! local parameters, variables and arrays
!

INTEGER(KIND=iintegers) :: &
  isec,               &
  info,               &
  istatus,            &
  jn,          &
  i, j, k, n,         &
  ncfileid, ncvarid,  & ! NetCDF IDs
  ier,                & ! return error code
  nx,                 & ! time index
  izerror,            &
  il_file_id,         &
  ierror,             &
  status

INTEGER(KIND=iintegers) :: &
  nrcvinfo(nfld_rcv_tot)  ! OASIS info argument

INTEGER(KIND=4)         :: &
  mask(nlei-nldi+1,nlej-nldj+1) ! mask array

REAL (KIND=ireals)      :: &
  ztmp1   (ie,je )




!------------------------------------------------------------------------------
!- End of header
!------------------------------------------------------------------------------

!------------------------------------------------------------------------------
! 1. Attribute fields to received fields (independent of the specific coupling) 
!-------------------------------------------------------------------------------

! Statement function zfpi for calculation of the exner function
! where the dummy argument zppa is pressure

! Coupling only with PEs that contain at least one land point

        ztmp1 (:,:) = 0.0_ireals
        isec = (ntstep - nstart ) * nint(dt)
   
  istatus=nf90_open('masks.nc', NF90_NOWRITE, ncfileid)
      istatus=nf90_inq_varid(ncfileid, 'coms.msk' , ncvarid)
      istatus=nf90_get_var(ncfileid, ncvarid, mask, &
       (/ isubpos(my_cart_id,1)-iboundstart,         &
          isubpos(my_cart_id,2)-jboundstart /),      &
        (/ nlei-nldi+1,nlej-nldj+1 /))
      istatus=nf90_close(ncfileid)

IF ( lpe_cpl ) THEN

  nrcvinfo (:) = OASIS_idle

!----------------------------------------------------------------------------
 jn=0
  DO jn = 1, nfld_rcv_tot
    IF( srcv(jn)%laction ) THEN
    CALL oas_cos_rcv( jn, isec, ztmp1(:,:), nrcvinfo(jn) )
    IF( nrcvinfo(jn) == OASIS_Rcv ) frcv(:,:,jn)=ztmp1(:,:)
  ENDIF
  ENDDO

!!ENDIF ! lpe_cpl
  ! Update non-masked t_s with frcv array
  ! SST index
   jn =  1
   IF( srcv(jn)%laction ) THEN
   WHERE (mask == 0) t_s(nldi:nlei,nldj:nlej,nnow) = frcv(nldi:nlei,nldj:nlej,jn) 
   WHERE (mask == 0) t_s(nldi:nlei,nldj:nlej,nnew) = frcv(nldi:nlei,nldj:nlej,jn) 
  ENDIF

ENDIF ! lpe_cpl
!----------------------------------------------------------------------------

END SUBROUTINE cos_receive_fld 


