SUBROUTINE cos_send_fld

!!---------------------------------------------------------------------
!!              ***  ROUTINE send_fld  ***
!!
!! ** Purpose : Prepare and send coupling fields to OASIS
!!      
!!----------------------------------------------------------------------

USE oas_cos_vardef

USE data_runcontrol,  ONLY : &
  ntstep,        &
  nnow,          &
  nnew,          &
  itype_gscp,    &
  nstart,        &
  ltime         

USE data_modelconfig, ONLY : &
  ke, ie, je,    &
  dt,            &
  ie_tot,        &
  je_tot,        &
  pollon,        &
  pollat,        &
  polgam

USE data_parameters,  ONLY : &
  ireals,        &
  iintegers

USE data_parallel,    ONLY : &
  isubpos,       & ! positions of the subdomains in the total domain
  nboundlines,   &    
  my_cart_id


USE data_constants,   ONLY : & 
  lh_v           ! latent heat of vapourization (2.501E6_ireals)  (J/kg)

USE data_fields,      ONLY : &
  ! 1. constant fields for the reference atmosphere                     (unit)
  prr_con    ,   & ! precipitation rate of rain, convective        (kg/m2*s)
  prs_con    ,   & ! precipitation rate of snow, convective        (kg/m2*s)
  prr_gsp    ,   & ! precipitation rate of rain, grid-scale        (kg/m2*s)
  prs_gsp    ,   & ! precipitation rate of snow, grid-scale        (kg/m2*s)
  prg_gsp    ,   & ! precipitation rate of graupel, grid-scale     (kg/m2*s)
 !   fields of the radiation
 lhfl_s      ,   & ! latent heat flux (surface)                    ( W/m2)
 shfl_s      ,   & ! sensible heat flux (surface)                  ( W/m2)
 sobs        ,   & ! solar radiation at the ground                 ( W/m2)
 thbs        ,   & ! thermal radiation at the ground               ( W/m2)
 !   momentum
 umfl_s      ,   & ! u-momentum flux (surface)                     ( N/m2)
 vmfl_s      ,   &    ! v-momentum flux (surface)                     ( N/m2)
runoff_s     ,  &      ! surface water runoff; sum over forecast       (kg/m2)
 runoff_g     
USE netcdf


USE utilities,        ONLY : & 
  phirot2phi

IMPLICIT NONE


INTEGER(KIND=iintegers) :: &
  istatus,              &
  ncfileid, ncvarid   ! NetCDF IDs            


INTEGER(KIND=iintegers) :: &
  isec,            &
  kinfo,           &
  ierror,          &
  status,          &
  ier,             &
  jn, jm, jo 

REAL(KIND=ireals)       :: &  
  ztprec (ie,je),  &
  ztevap (ie,je),  &
  zt_ns (ie, je),  &
  zt_emp (ie, je),  & 
  ztemp(ie, je),   &
  ztemp_g(ie, je)
!------------------------------------------------------------------------------
!- End of header
!------------------------------------------------------------------------------

!----------------------------------------------------------------------------
! 1 coupling-specific handling of sent fields
!----------------------------------------------------------------------------

! Coupling only on PE with at least one unmasked grid point
IF ( lpe_cpl ) THEN

  !isec = ntstep * dt
  isec = (ntstep - nstart ) * nint(dt)

!!IF (ltime) CALL get_timings (i_cpl_put, ntstep, dt, ierror)
!----------------------------------------------------------------------------
! 1.4 nemoO- and romsO-specific handling of sent fields
!----------------------------------------------------------------------------
  
    
    
    jn =  1
    IF( ssnd(jn)%laction ) THEN
      ztprec = prr_con + prs_con + prr_gsp + prs_gsp
      IF (itype_gscp == 4 ) ztprec = ztprec + prg_gsp 
        !   the surface freshwater flux is calculated, should be positiv downward
        !   for nemo, so the sign is changed
        ztevap = lhfl_s/lh_v
       ztprec = ztprec
       ztevap = ztevap 
       zt_emp = -ztevap - ztprec
        CALL oas_cos_snd (jn, isec, zt_emp, kinfo )
      ENDIF
      jn = jn + 1
      umfl_s = umfl_s
      IF( ssnd(jn)%laction ) CALL oas_cos_snd (jn, isec, umfl_s, kinfo )
      jn = jn + 1
      vmfl_s = vmfl_s
      IF( ssnd(jn)%laction ) CALL oas_cos_snd (jn, isec, vmfl_s, kinfo ) 
      jn = jn + 1
     sobs = sobs
      IF( ssnd(jn)%laction ) CALL oas_cos_snd (jn, isec, sobs, kinfo )
      jn = jn + 1
      IF( ssnd(jn)%laction ) THEN
        zt_ns = thbs + lhfl_s + shfl_s
       CALL oas_cos_snd (jn, isec, zt_ns, kinfo )
    ENDIF
        jn = jn + 1
        ztemp = zt_emp /10800.0 
  IF( ssnd(jn)%laction )  CALL oas_cos_snd_black_sea (jn, isec, ztemp, kinfo )    
        ztemp =  runoff_s     ! RUNOFF_S [kg/m2]
    jn = jn + 1
       WHERE ( runoff_s < 0. ) ztemp = 0.
    IF( ssnd(jn)%laction )  CALL oas_cos_snd (jn, isec, ztemp, kinfo )

    jn = jn + 1
     ztemp_g =  runoff_g         ! RUNOFF_G [kg/m2] 
     WHERE ( runoff_g < 0. ) ztemp_g = 0.
    IF( ssnd(jn)%laction ) CALL oas_cos_snd (jn, isec, ztemp_g, kinfo )


ENDIF
!!IF (ltime) CALL get_timings (i_cpl_put, ntstep, dt, ierror)

END SUBROUTINE cos_send_fld 

