#if defined COUP_OAS
SUBROUTINE oas_cos_rcv( kid, kstep, pdata, kinfo )

!!---------------------------------------------------------------------
!!              ***  ROUTINE oas_cos_rcv  ***
!!
!! ** Purpose : - At each coupling time-step,this routine call fields
!!                from the coupler or remote application.
!!----------------------------------------------------------------------

USE data_parameters,    ONLY : & 
  ireals,                      &
  iintegers

USE data_modelconfig,   ONLY : &
  ie,                          &
  je

USE data_parallel,      ONLY : &
  my_cart_id

USE oas_cos_vardef

!EM 24.08.2012 Switch for OASIS3-MCT compatibility
#if ! defined OASIS3MCT
      USE mod_prism_get_proto
#endif
!EM end

IMPLICIT NONE

INTEGER(kind=iintegers), INTENT(IN)   :: &
  kid    ! variable index in the array

INTEGER(kind=iintegers), INTENT(IN)   :: &
  kstep  ! time-step in seconds

REAL(kind=ireals), INTENT(OUT)        :: &
  pdata(ie,je)

INTEGER(kind=iintegers), INTENT(OUT)  :: &
  kinfo  ! OASIS info argument

!!
!! local variables
!!
LOGICAL :: &
  llaction
!!--------------------------------------------------------------------

!  Masked points are not modified by OASIS
!  = buffer set to 0 before calling OASIS
exfld(:,:) = 0.0_ireals

IF (lpe_cpl) THEN

  ! receive local data from OASIS on every process involved in the coupling
  CALL prism_get_proto ( srcv(kid)%nid, kstep, exfld(nldi:nlei, nldj:nlej), kinfo )         
  IF ( nerror /= PRISM_Success) THEN
    CALL prism_abort_proto( srcv(kid)%nid, 'oas_cos_rcv', &
      'Failure in prism_get_proto for '//TRIM(srcv(kid)%clname) )
  ENDIF

  llaction = .false.
  IF( kinfo == PRISM_Recvd   .OR. kinfo == PRISM_FromRest .OR.   &
      kinfo == PRISM_RecvOut .OR. kinfo == PRISM_FromRestOut .OR. kinfo == PRISM_Input)   llaction = .TRUE.
       
  ! If coupling time step
  IF ( llaction ) THEN

    ! Declare to calling routine that OASIS provided coupling field
    kinfo = OASIS_Rcv

    ! Update array which contains coupling field (only on valid shape)
     pdata(nldi:nlei, nldj:nlej) = exfld(nldi:nlei, nldj:nlej)

    IF ( debug_oasis > 1  .AND. my_cart_id == 0 ) THEN
      WRITE(nulout,*) '************ in oas_cos_rcv *********'
      WRITE(nulout,*) 'prism_get_proto: Incoming ', srcv(kid)%clname
      WRITE(nulout,*) 'prism_get_proto: ivarid '  , srcv(kid)%nid
      WRITE(nulout,*) 'prism_get_proto:   kstep', kstep
      WRITE(nulout,*) 'prism_get_proto:   info ', kinfo
      WRITE(nulout,*) '     - Minimum value is ', MINVAL(pdata)
      WRITE(nulout,*) '     - Maximum value is ', MAXVAL(pdata)
      WRITE(nulout,*) '     -     Sum value is ', SUM(pdata)
      WRITE(nulout,*) '*************************************'
      CALL flush(nulout)
    ENDIF
  ELSE
    ! Declare to calling routine that OASIS did not provide coupling field
    kinfo = OASIS_idle     
  ENDIF

ENDIF ! lpe_cpl

END SUBROUTINE oas_cos_rcv
#endif

