#if defined COUP_OAS
SUBROUTINE oas_cos_snd( kid, kstep, pdata, kinfo)

!!---------------------------------------------------------------------
!!              ***  ROUTINE oas_cos_snd  ***
!!
!! ** Purpose : - At each coupling time-step,this routine sends fields
!!                to the coupler or remote application.
!!----------------------------------------------------------------------

USE data_parameters,  ONLY : &
  ireals,                    &
  iintegers
USE netcdf
USE data_modelconfig, ONLY : &
  ie,                        &
  je

USE data_parallel,    ONLY : &
  my_cart_id,           &
  isubpos,              &
  icomm_world

USE parallel_utilities, ONLY :  global_values
USE oas_cos_vardef

#if ! defined OASIS3MCT
!EM 24.08.2012 Switch for OASIS3-MCT compatibility
USE mod_prism_put_proto
!EM end
#endif

IMPLICIT NONE

!! * Arguments
!!
INTEGER(kind=iintegers), INTENT(IN)    ::  &
  kid    ! variable index in the array

INTEGER(kind=iintegers), INTENT(OUT)   ::  &
  kinfo  ! OASIS info argument

INTEGER(kind=iintegers), INTENT(IN)    ::  &
  kstep  ! time-step in seconds

REAL(kind=ireals), INTENT(IN)          ::  &
  pdata(ie,je)
LOGICAL                 :: llaction

!!
!! * Local variables
!!
!!
!!--------------------------------------------------------------------
!


IF ( lpe_cpl ) THEN
  !
  !
  ! prepare array (only valid shape, without halos) for OASIS
  !
  exfld(nldi:nlei, nldj:nlej) = pdata(nldi:nlei, nldj:nlej)

  ! Call OASIS at each time step but field is sent to other model only at coupling time step
  ! (accumulation otherwise, if asked in the namcouple configuration file)
  !
  CALL prism_put_proto( ssnd(kid)%nid, kstep, exfld(nldi:nlei, nldj:nlej), kinfo)
 
  llaction = .false.
      IF( kinfo == PRISM_Sent   .OR. kinfo == PRISM_ToRest .OR.   &
          kinfo == PRISM_Output .OR. kinfo == PRISM_SentOut .OR. kinfo ==PRISM_ToRestOut)   llaction = .TRUE.

 
 
  IF ( debug_oasis > 1 .AND. my_cart_id == 0 ) THEN
    WRITE(nulout,*) '************ in oas_cos_snd *********'
    WRITE(nulout,*) 'prism_put: Incoming ', ssnd(kid)%clname
    WRITE(nulout,*) 'prism_put: ivarid '  , ssnd(kid)%nid
    WRITE(nulout,*) 'prism_put:   kstep', kstep
    WRITE(nulout,*) 'prism_put:   info ', kinfo
    WRITE(nulout,*) '     - Minimum value is ', MINVAL(pdata(nldi:nlei, nldj:nlej))
    WRITE(nulout,*) '     - Maximum value is ', MAXVAL(pdata(nldi:nlei, nldj:nlej))
    WRITE(nulout,*) '     -     Sum value is ', SUM(pdata(nldi:nlei, nldj:nlej))
    WRITE(nulout,*) '*************************************'
    CALL flush(nulout)
  ENDIF

ENDIF ! lpe_cpl

END SUBROUTINE oas_cos_snd

SUBROUTINE oas_cos_snd_black_sea( kid, kstep, pdata, kinfo)

!!---------------------------------------------------------------------
!!              ***  ROUTINE oas_cos_snd  ***
!!
!! ** Purpose : - At each coupling time-step,this routine sends fields
!!                to the coupler or remote application.
!!----------------------------------------------------------------------

USE data_parameters,  ONLY : &
  ireals,                    &
  iintegers
USE netcdf
USE data_modelconfig, ONLY : &
  ie,                        &
  je,                        &
  ie_tot,                    &
  je_tot   

USE data_parallel,    ONLY : &
  my_cart_id,           &
  isubpos, icomm_cart, icomm_world, imp_integers,imp_reals,  num_compute

USE parallel_utilities, ONLY :  distribute_values, &
                                gather_field
                                
USE oas_cos_vardef

#if ! defined OASIS3MCT
!EM 24.08.2012 Switch for OASIS3-MCT compatibility
USE mod_prism_put_proto
!EM end
#endif

IMPLICIT NONE

!! * Arguments
!!
INTEGER(kind=iintegers), INTENT(IN)    ::  &
  kid    ! variable index in the array

INTEGER(kind=iintegers), INTENT(OUT)   ::  &
  kinfo  ! OASIS info argument

INTEGER(kind=iintegers), INTENT(IN)    ::  &
  kstep  ! time-step in seconds

REAL(kind=ireals), INTENT(IN)          ::  &
  pdata(ie,je)
LOGICAL                 :: llaction

INTEGER(KIND=iintegers) :: &
  istatus,              &
  ncfileid, ncvarid, izerror   ! NetCDF IDs
REAL(KIND=ireals)       :: &
  ztblack
REAL(KIND=ireals)       :: &
  exfld2(ie,je),    & 
 exfld_tot(ie_tot,je_tot)
INTEGER(KIND=4)         :: &
  blacksea_mask(nldi:nlei, nldj:nlej) ! mask array
 CHARACTER (LEN=80)       ::  &
    yzerrmsg
izerror  = 0
yzerrmsg = '   '

!!
!! * Local variables
!!
!!
!!--------------------------------------------------------------------
!
!--------------------------------------------------------------------
!
        
  istatus=nf90_open('masks.nc', NF90_NOWRITE, ncfileid)
      istatus=nf90_inq_varid(ncfileid, 'bbse.msk' , ncvarid)
      istatus=nf90_get_var(ncfileid, ncvarid, blacksea_mask, &
       (/ isubpos(my_cart_id,1)-iboundstart,         &
          isubpos(my_cart_id,2)-jboundstart /),      &
        (/ nlei-nldi+1,nlej-nldj+1 /))
      istatus=nf90_close(ncfileid)

    
IF ( lpe_cpl ) THEN
  !
  !
  ! prepare array (only valid shape, without halos) for OASIS
  !
   
  exfld(nldi:nlei, nldj:nlej) = pdata(nldi:nlei, nldj:nlej)

  
 ! mask the Black Sea values
     
  exfld(nldi:nlei, nldj:nlej) = blacksea_mask(nldi:nlei, nldj:nlej) *exfld(nldi:nlei, nldj:nlej)
  exfld2(nldi:nlei, nldj:nlej) =exfld(nldi:nlei, nldj:nlej) 
  
 ! gather the field to sum the E-P over the Black Sea
  
     CALL gather_field(exfld2,ie,je,exfld_tot(:,:),ie_tot,je_tot,0,nerror)
   
  IF ( my_cart_id == 0 ) THEN
     ztblack = SUM(exfld_tot(:,:))
   ENDIF

  ! distrube the Black Sea E-P 
   CALL distribute_values  (ztblack, 1, 0, imp_reals, icomm_world, nerror) 
 
  exfld2(nldi:nlei, nldj:nlej) = 1.0 
  exfld2 = exfld2* ztblack 
 
 ! Call OASIS at each time step but field is sent to other model only at
  ! coupling time step
  ! (accumulation otherwise, if asked in the namcouple configuration file)

   CALL prism_put_proto( ssnd(kid)%nid, kstep, exfld2(nldi:nlei, nldj:nlej), kinfo)

  llaction = .false.
      IF( kinfo == PRISM_Sent   .OR. kinfo == PRISM_ToRest .OR.   &
          kinfo == PRISM_Output .OR. kinfo == PRISM_SentOut .OR. kinfo==PRISM_ToRestOut)   llaction = .TRUE.



  IF ( debug_oasis > 1 .AND. my_cart_id == 0 ) THEN
    WRITE(nulout,*) '************ in oas_cos_snd *********'
    WRITE(nulout,*) 'prism_put: Incoming ', ssnd(kid)%clname
    WRITE(nulout,*) 'prism_put: ivarid '  , ssnd(kid)%nid
    WRITE(nulout,*) 'prism_put:   kstep', kstep
    WRITE(nulout,*) 'prism_put:   info ', kinfo
    WRITE(nulout,*) '     - Minimum value is ', MINVAL(pdata(nldi:nlei,nldj:nlej))
    WRITE(nulout,*) '     - Maximum value is ', MAXVAL(pdata(nldi:nlei,nldj:nlej))
    WRITE(nulout,*) '     -     Sum value is ', SUM(pdata(nldi:nlei, nldj:nlej))
   WRITE(nulout,*) '     -    exfld Sum value is ', SUM(exfld2(nldi:nlei, nldj:nlej)) 
   WRITE(nulout,*) '     -  ztblack  Sum value is ',ztblack
   WRITE(nulout,*) '     -  exfld  Sum value is ', SIZE(exfld) 
   WRITE(nulout,*) '     -  exfld_tot  Sum value is ', SIZE(exfld_tot)
    WRITE(nulout,*) '*************************************'
    CALL flush(nulout)
  ENDIF

ENDIF ! lpe_cpl

END SUBROUTINE oas_cos_snd_black_sea
#endif
