MODULE oas_cos_vardef

!**** *oas_cos_vardef * - Controls, definitions and variables
!                   for OASIS communications
!
!     AUTHOR.
!     -------
!     2007-1-30 Kristian Mogensen
!
!     MODIFICATIONS.
!     --------------
!     2010-3  Eric Maisonnave: OASIS4
!     2010-11 Eric Maisonnave: COSMO-CLM coupling
!     A. Dobler: adapted to OASIS3
!     Naveed Akhtar: adapted to OASIS3-MCT2 
!    2012-08: unified interface for OASIS - COSMO/CLM, Will/Davin/Brauch 
!    2017 Naveed Akhtar implemented coupling TRIP river routing scheme
!    2017 Naveed Akhtar implemented E-P of Black Sea coupling
!****

USE data_parameters,     ONLY: &
  ireals,             &
  iintegers

#ifdef OASIS3MCT
!JPB 07.09.2012 this is not used and causes a conflict
  USE mpi
!JPB end
  USE mod_prism                    ! OASIS3-MCT prism module
#else
  USE mod_prism_proto              ! OASIS3 prism module
  USE mod_prism_def_partition_proto! OASIS3 prism module for partitioning
  USE mod_prism_grids_writing      ! OASIS3 prism module for writing grid files
  USE mod_prism_put_proto          ! OASIS3 prism module for snding
  USE mod_prism_get_proto          ! OASIS3 prism module for receiving
#endif


IMPLICIT NONE

SAVE

! Debug level of OASIS
!     0 : Minimum debugging
!     1 : Debugging
!     2 : Perfs measurement
!     3 : OASIS restart production

INTEGER(KIND=iintegers) :: &
  debug_oasis=2,             & ! Debug level of OASIS
  ncomp_id,                & ! id returned by prism_init_comp   
  kl_comm,                 & ! Local communicator
  nerror,                  & ! return error code
  nldi,nlei,nldj,nlej,     & ! halo limits on a local subdomain
  jih,jjh,                 & ! subdomain limit
  iboundstart,jboundstart    ! boundline limits limit

INTEGER(KIND=iintegers) :: &
  OASIS_Rcv  = 1,          & ! return code if received field
  OASIS_idle = 0,          & ! return code if nothing was done by OASIS
  PRISM_Success = 0          ! return code if no error in OASIS

INTEGER(KIND=iintegers) :: &
  nulout=6                   ! unit number for joblog file

TYPE :: FLD_CPL                        ! Type for coupling field information
  LOGICAL                 :: laction   ! To be coupled or not
  CHARACTER(LEN = 8)      :: clname    ! Name of the coupling field
  CHARACTER(LEN = 1)      :: clgrid    ! Grid type
  INTEGER(KIND=iintegers) :: nid       ! Id of the field
END TYPE FLD_CPL

TYPE(FLD_CPL), ALLOCATABLE :: &
  srcv(:),                 & ! All fields to be received
  ssnd(:)                    ! All fields to be sent

REAL(KIND=ireals), ALLOCATABLE :: &
  exfld (:,:),            & ! Temporary buffer for receiving
  frcv  (:,:,:)             ! all fields recieved from coupled model

LOGICAL :: &
  lpe_cpl = .FALSE.
 


INTEGER(KIND=iintegers) :: &
  nfld,                    & !
  nfld_snd_tot,            & ! total number of fields to be sent
  nfld_rcv_tot,            & ! total number of fields to be received
  nfld_snd_oce,            & !
  nfld_rcv_oce,            & !
  write_aux_files            ! write OASIS auxiliary files

INTEGER(kind=iintegers) :: IOASISDEBUGLVL = 1

INTEGER(KIND=iintegers), ALLOCATABLE :: &
  nlev_snd_oce(:),         & !
  nlev_rcv_oce(:)            !
 INTEGER(kind=iintegers), PARAMETER :: nmaxfld=20    ! Maximum number ofcoupling fields
   INTEGER(kind=iintegers)            :: ksnd, krcv    ! Number of send/receivedcoupling fields
CHARACTER(LEN=8), ALLOCATABLE :: &
  nam_snd_oce(:),          & !
  nam_rcv_oce(:)             !


END MODULE oas_cos_vardef
